@@ -10,7 +10,7 @@
 char *HashSHA512FromFile(char *filename) {
 	FILE *fp = fopen(filename, "rb");
 	if (fp == NULL) {
-		printf("chest::HashSHA512FromFile() error: Cannot open %s: %s\n",
+		printf("chest:HashSHA512FromFile() error: Cannot open %s: %s\n",
 			filename, strerror(errno));
 		exit(1);
 	}
@@ -21,7 +21,7 @@ char *HashSHA512FromFile(char *filename) {
 
 	char *pw = malloc(filesize);
 	if (pw == NULL) {
-		printf("chest::HashSHA512FromString() error: malloc() returned NULL, exiting.\n");
+		printf("chest:HashSHA512FromString() error: malloc() returned NULL, exiting.\n");
 		fclose(fp);
 		exit(ENOMEM);
 	}
@@ -30,7 +30,7 @@ char *HashSHA512FromFile(char *filename) {
 
 	char *sum = malloc(SHA512_DIGEST_LENGTH);
 	if (sum == NULL) {
-		printf("chest::HashSHA512FromFile() error: malloc() returned NULL, exiting.\n");
+		printf("chest:HashSHA512FromFile() error: malloc() returned NULL, exiting.\n");
 		exit(1);
 	}
 	memset(sum, 0, SHA512_DIGEST_LENGTH);
@@ -45,7 +45,7 @@ char *HashSHA512FromFile(char *filename) {
 char *HashSHA512FromString(const char *pw) {
 	char *sum = malloc(SHA512_DIGEST_LENGTH);
 	if (sum == NULL) {
-		printf("chest::HashSHA512FromString() error: malloc() returned NULL, exiting.\n");
+		printf("chest:HashSHA512FromString() error: malloc() returned NULL, exiting.\n");
 		exit(ENOMEM);
 	}
 	memset(sum, 0, SHA512_DIGEST_LENGTH);
